==> cyrus-imapd-2.1.3.tar.gz: cyrus-imapd-2.1.3/notifyd/notify_log.c <==
/* notify_log.c -- syslog notification method
 * Ken Murchison
 */
/*
 * Copyright (c) 1999-2000 Carnegie Mellon University.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name "Carnegie Mellon University" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For permission or any other legal
 *    details, please contact  
 *      Office of Technology Transfer
 *      Carnegie Mellon University
 *      5000 Forbes Avenue
 *      Pittsburgh, PA  15213-3890
 *      (412) 268-4387, fax: (412) 268-7395
 *      tech-transfer@andrew.cmu.edu
 *
 * 4. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by Computing Services
 *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
 *
 * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
 * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * $Id: notify_log.c,v 1.2 2002/03/01 20:24:27 ken3 Exp $
 */

#include "notify_log.h"

#include <syslog.h>
#include <string.h>
#include <stdio.h>

char* notify_log(int nopt, char **options, const char *priority,
		 const char *message)
{
    char opt_str[1024] = "";
    char *sep = "";
    int i;

    if (nopt) {
	strcpy(opt_str, "(");
	for (i = 0; i < nopt; i++, sep = ", ") {
	    snprintf(opt_str+strlen(opt_str), sizeof(opt_str) - 2, "%s%s",
		     sep, options[i]);
	}
	strcat(opt_str, ") ");
    }

    openlog("notifyd", LOG_PID, LOG_LOCAL6);
    syslog(LOG_INFO, "[%s] %s\"%s\"", priority, opt_str, message);
    closelog();

    return strdup("OK log notification successful");
}

==> cyrus-imapd-2.1.4.tar.gz: cyrus-imapd-2.1.4/notifyd/notify_log.c <==
/* notify_log.c -- syslog notification method
 * Ken Murchison
 */
/*
 * Copyright (c) 1999-2000 Carnegie Mellon University.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name "Carnegie Mellon University" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For permission or any other legal
 *    details, please contact  
 *      Office of Technology Transfer
 *      Carnegie Mellon University
 *      5000 Forbes Avenue
 *      Pittsburgh, PA  15213-3890
 *      (412) 268-4387, fax: (412) 268-7395
 *      tech-transfer@andrew.cmu.edu
 *
 * 4. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by Computing Services
 *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
 *
 * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
 * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * $Id: notify_log.c,v 1.3 2002/03/18 15:14:17 ken3 Exp $
 */

#include "notify_log.h"

#include <syslog.h>
#include <string.h>
#include <stdio.h>

char* notify_log(const char *class, const char *priority,
		 const char *user, const char *mailbox,
		 int nopt, char **options,
		 const char *message)
{
    char opt_str[1024] = "";
    char *sep = "";
    int i;

    if (nopt) {
	strcpy(opt_str, "(");
	for (i = 0; i < nopt; i++, sep = ", ") {
	    snprintf(opt_str+strlen(opt_str), sizeof(opt_str) - 2, "%s%s",
		     sep, options[i]);
	}
	strcat(opt_str, ")");
    }

    openlog("notifyd", LOG_PID, LOG_LOCAL6);
    syslog(LOG_INFO, "%s, %s, %s, %s, %s \"%s\"",
	   class, priority, user, mailbox, opt_str, message);
    closelog();

    return strdup("OK log notification successful");
}
